ImageResource

Struct ImageResource 

pub struct ImageResource {
    pub width: u16,
    pub height: u16,
    pub atlas_id: AtlasId,
    pub offset: [u16; 2],
    pub padding: u16,
    atlas_alloc_id: AllocId,
}
Represents an image resource for rendering.

Fields

width: u16

The width of the image.

height: u16

The height of the image.

atlas_id: AtlasId

The Id of the atlas containing this image.

offset: [u16; 2]

The offset of the image within its atlas (does not include padding, i.e. it points to the position of the first actual top-left pixel).

padding: u16

The number of transparent padding pixels around the image in the atlas.

atlas_alloc_id: AllocId

The atlas allocation ID for deallocation.

Implementations

Source

impl ImageResource

pub fn offsets(&self) -> [u32; 2]

Returns the offset as [u32; 2].

pub fn size(&self) -> [u32; 2]

Returns the size as [u32; 2].